Crate violet_spatial_decoder

Crate violet_spatial_decoder 

Adds a spatial decoder input to xpans Violet

Supported Formats

The only supported format is xpans Spatial Record (XSR), as it is the only format in the xpans Ecosystem at the time of writing. In the future, more formats and spatial codecs will be supported.

Structs

SpatialDecoder
The actual spatial input that the renderer gets spatial data from.
SpatialDecoderInfo
Stores metadata about the spatial stream. Splits into a SpatialDecoder and SpatialDecoderTask.
SpatialDecoderTask
Contains data necessary to start the spatial decoder process.