pub struct SpatialDecoderInfo<Scene, T>{ /* private fields */ }Expand description
Stores metadata about the spatial stream.
Splits into a SpatialDecoder and SpatialDecoderTask.
Implementations
Sourceimpl<Scene, T> SpatialDecoderInfo<Scene, T>
impl<Scene, T> SpatialDecoderInfo<Scene, T>
Sourcepub fn new(scene: Scene, source_count: usize, duration: usize) -> Self
pub fn new(scene: Scene, source_count: usize, duration: usize) -> Self
Creates a SpatialDecoderInfo using a xpans Spatial Record (XSR) map.
The source count and duration (in samples) of the scene must also be given.
Sourcepub fn into_pair(
self,
write_capacity: usize,
) -> (SpatialDecoder<T>, SpatialDecoderTask<Scene, T>)
pub fn into_pair( self, write_capacity: usize, ) -> (SpatialDecoder<T>, SpatialDecoderTask<Scene, T>)
Splits this struct into a SpatialDecoder and SpatialDecoderTask.
The resulting SpatialDecoder is the input you will give the renderer,
and the SpatialDecoderTask allows you to spawn the decoder task that
can decode the stream on a seperate thread.