SpatialDecoderInfo

Struct SpatialDecoderInfo 

pub struct SpatialDecoderInfo<Scene, T>
where Scene: AsRef<SpatialSampleMap<usize, u16, T>>,
{ /* private fields */ }
Stores metadata about the spatial stream. Splits into a SpatialDecoder and SpatialDecoderTask.

Implementations

Source

impl<Scene, T> SpatialDecoderInfo<Scene, T>
where T: Copy + Default, Scene: AsRef<SpatialSampleMap<usize, u16, T>>,

pub fn new(scene: Scene, source_count: usize, duration: usize) -> Self

Creates a SpatialDecoderInfo using a xpans Spatial Record (XSR) map.

The source count and duration (in samples) of the scene must also be given.

pub fn into_pair( self, write_capacity: usize, ) -> (SpatialDecoder<T>, SpatialDecoderTask<Scene, T>)

Splits this struct into a SpatialDecoder and SpatialDecoderTask.

The resulting SpatialDecoder is the input you will give the renderer, and the SpatialDecoderTask allows you to spawn the decoder task that can decode the stream on a seperate thread.